@@ -12,17 +12,15 @@ ch.setFormatter(formatter)
 logger.addHandler(ch)
 logger.setLevel(logging.WARNING)
 
-MONGO_ADDR = 'mongodb://192.168.0.173:27017'
-
 
 class CorpsEval:
     """eval에서 사용되는 여러가지 지수를 계산하는 함수 모음.
 
     """
-    client = mongo2.connect_mongo(MONGO_ADDR)
 
-    def __init__(self, code: str):
+    def __init__(self,client, code: str):
         if utils.is_6digit(code):
+            self.client = client
             self.code = code
             self.c101 = mongo2.C101(self.client, code)
             self.c103 = mongo2.C103(self.client, code, 'c103재무상태표y')
