@@ -1,7 +1,7 @@
 import math
 import numpy
 import pprint
-from .db import CorpsEval, MONGO_ADDR
+from .db import CorpsEval
 from .eval import EXPECT_EARN, red as eval_red, mil as eval_mil, blue as eval_blue, growth as eval_growth
 
 from db_hj3415 import mongo2
@@ -19,7 +19,7 @@ logger.addHandler(ch)
 logger.setLevel(logging.WARNING)
 
 
-def red(code: str) -> tuple:
+def red(client, code: str) -> tuple:
     """red price와 최근 주가의 괴리율 파악
 
     양수면 주가가 고평가되어 있는 상태, 음수면 저평가
@@ -33,7 +33,6 @@ def red(code: str) -> tuple:
         {'red_price': 47896, '사업가치': 7127.5, '재산가치': 7152.78, '부채평가': 902.4, '발행주식수': 27931.0}\n
     """
     if utils.is_6digit(code):
-        client = mongo2.connect_mongo(MONGO_ADDR)
         c101 = mongo2.C101(client, code)
     else:
         raise ValueError(f'Invalid code: {code}')
@@ -70,7 +69,7 @@ def red(code: str) -> tuple:
             return 0, 괴리율
 
 
-def mil(code: str) -> tuple:
+def mil(client, code: str) -> tuple:
     """
     - 재무활동현금흐름이 마이너스라는 것은 배당급 지급했거나, 자사주 매입했거나, 부채를 상환한 상태임.
     - 반대는 채권자로 자금을 조달했거나 신주를 발행했다는 의미
@@ -111,11 +110,10 @@ def mil(code: str) -> tuple:
     """
 
     if utils.is_6digit(code):
-        corps_eval = CorpsEval(code)
+        corps_eval = CorpsEval(client, code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    client = mongo2.connect_mongo(MONGO_ADDR)
     mil_dict = eval_mil(client, code)
 
     logger.info(pprint.pformat(mil_dict, width=200))
@@ -162,7 +160,7 @@ def mil(code: str) -> tuple:
     return p1, p2, p3, p4
 
 
-def blue(code: str) -> tuple:
+def blue(client, code: str) -> tuple:
     """회사의 안정성을 보는 지표들
 
     0을 기준으로 상태가 좋치 않을 수록 마이너스 값을 가진다.
@@ -213,7 +211,6 @@ def blue(code: str) -> tuple:
         return int(p)
 
     if utils.is_6digit(code):
-        client = mongo2.connect_mongo(MONGO_ADDR)
         corps_eval = CorpsEval(code)
         c104 = mongo2.C104(client, code, 'c104y')
     else:
@@ -301,7 +298,7 @@ def blue(code: str) -> tuple:
     return p1, p2, p3, p4, p5
 
 
-def growth(code: str) -> tuple:
+def growth(client, code: str) -> tuple:
     """회사의 성장성을 보는 지표들
 
     <매출액>
@@ -319,11 +316,10 @@ def growth(code: str) -> tuple:
     """
 
     if utils.is_6digit(code):
-        corps_eval = CorpsEval(code)
+        corps_eval = CorpsEval(client, code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    client = mongo2.connect_mongo(MONGO_ADDR)
     growth_dict = eval_growth(client, code)
 
     logger.debug(pprint.pformat(growth_dict, width=200))
